@@ -88,6 +88,8 @@ nepim_global_t nepim_global = {
   -1,       /* server_write_floor (bytes) */
   -1,       /* server_write_ceil (bytes) */
   1,        /* udp_accumulative_loss (boolean) */
+  0,        /* udp_dst_random_addr (0=fixed,1=random) */
+  0,        /* udp_dst_random_port (0=fixed,1=random) */
 
   0, /* oop source */
   0  /* source interface */
