@@ -93,6 +93,8 @@ struct nepim_global_t {
   int           server_write_floor; /* bytes */
   int           server_write_ceil;  /* bytes */
   int           udp_accumulative_loss; /* boolean */
+  int           udp_dst_random_addr;   /* 0=fixed,1=random */
+  int           udp_dst_random_port;   /* 0=fixed,1=random */
 
   oop_source_sys *oop_sys;
   oop_source     *oop_src;
