@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.65 2007/03/22 21:56:53 evertonm Exp $
+  $Id: main.c,v 1.67 2007/08/17 17:12:48 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -108,16 +108,19 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -L             supress output of UDP accumulative loss\n"
 	  "\n"
           "client-only options:\n"
+          "  -c host-list   client mode (defaults to server mode)\n"
           "  -u             UDP mode (defaults to TCP)\n"
           "  -s             client-send simplex mode (defaults to server-send)\n"
-	  "  -F             force sending out UDP regardless of server\n"
           "  -d             duplex traffic (defaults to simplex)\n"
+	  "  -F             force sending out UDP regardless of server\n"
+	  "  -Fa            same as -F plus randomize destination address\n"
+	  "  -Fp            same as -F plus randomize destination port\n"
+	  "                 if -c is omitted, either 'a' or 'p' implies -c 1.1.1.1\n"
           "  -M             enable multicast-compatible options\n"
 	  "  -o [overhead]  protocol per-packet overhead in bytes (defaults to none)\n"
 	  "                 if the optional 'overhead' argument is ommited:\n"
 	  "                 UDP overhead defaults to %d\n"
 	  "                 TCP overhead defaults to %d\n"
-          "  -c host-list   client mode (defaults to server mode)\n"
           "  -n pipes       number of parallel pipes (defaults to %d)\n"
           "  -r bit-rate    upper bit rate limit (defaults to %s bps)\n"
           "  -R pkt-rate    upper packet rate limit (defaults to %s pps)\n"
@@ -650,12 +653,33 @@ int main(int argc, const char *argv[])
       continue;
     }
 
-    if (!strcmp(arg, "-F")) {
+    if (!strncmp(arg, "-F", 2)) {
       nepim_global.udp_mode                = 1; /* -u (UDP) */
       nepim_global.simplex_client_send     = 1; /* -s (client-send) */
       nepim_global.udp_keepalive_require   = 0; /* boolean */
       nepim_global.udp_require_greet_reply = 0; /* boolean */
       nepim_global.max_greetings           = 0; /* counter */
+
+      /* -Fa ? */
+      if (strchr(arg + 1, 'a')) {
+	nepim_global.udp_dst_random_addr = 1; /* 0=fixed,1=random */
+
+	/* force -c */
+	nepim_global.client_mode = 1;
+	if (!nepim_global.hostname)
+	  nepim_global.hostname = addr_list_append(nepim_global.hostname, "1.1.1.1");
+      }
+
+      /* -Fp ? */
+      if (strchr(arg + 1, 'p')) {
+	nepim_global.udp_dst_random_port = 1; /* 0=fixed,1=random */
+
+	/* force -c */
+	nepim_global.client_mode = 1;
+	if (!nepim_global.hostname)
+	  nepim_global.hostname = addr_list_append(nepim_global.hostname, "1.1.1.1");
+      }
+
       continue;
     }
 
