@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: slot.c,v 1.45 2007/03/22 21:56:53 evertonm Exp $ */
+/* $Id: slot.c,v 1.48 2007/08/17 17:12:48 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -32,6 +32,8 @@ MA 02110-1301 USA
 #include "usock.h"
 #include "udp_header.h"
 #include "common.h"
+#include "sock.h"
+#include "rand.h"
 
 extern nepim_usock_set_t udp_tab; /* from server.c */
 
@@ -222,9 +224,52 @@ int nepim_slot_buf_sendto(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_
 
   slot_buf_write(slot, buf, buf_size, type);
 
+  /* Randomize destination address? */
+  if (nepim_global.udp_dst_random_addr) {
+    int family = nepim_sock_family((const struct sockaddr *) &slot->session.remote);
+    switch (family) {
+    case PF_INET:
+      {
+	uint32_t random_addr = nepim_urand_next(&slot->session.udp_dst_random_ctx);
+	slot->session.remote.inet.sin_addr.s_addr = random_addr;
+      }
+      break;
+    case PF_INET6:
+      {
+	int i;
+	for (i = 0; i < 4; ++i)
+	  slot->session.remote.inet6.sin6_addr.in6_u.u6_addr32[i] =
+	    nepim_urand_next(&slot->session.udp_dst_random_ctx);
+      }
+      break;
+    default:
+      assert(0);
+    }
+  }
+
+  /* Randomize destination port? */
+  if (nepim_global.udp_dst_random_port) {
+    int random_port = nepim_rand_next(&slot->session.udp_dst_random_ctx, 0, 65535);
+    nepim_sock_set_port((const struct sockaddr *) &slot->session.remote,
+			random_port);
+  }
+
   wr = sendto(slot->udp_sd, buf, buf_size, 0,
 	      (const struct sockaddr *) &slot->session.remote,
 	      slot->session.remote_len);
+  if (wr < 1)
+    if (nepim_global.verbose_stderr) {
+      char addr_buf[500];
+      nepim_sock_dump_addr(addr_buf, sizeof addr_buf,
+			   (const struct sockaddr *) &slot->session.remote,
+			   slot->session.remote_len);
+      fprintf(nepim_global.verbose_stderr,
+	      "%s %s: sendto(dst=%s,%d len=%d): sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      addr_buf,
+	      nepim_sock_get_port((const struct sockaddr *) &slot->session.remote),
+	      slot->session.remote_len, slot->udp_sd, errno, strerror(errno));
+    }
 
   return wr;
 }
@@ -233,6 +278,9 @@ int nepim_slot_buf_write(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_t
 {
   ssize_t wr;
 
+  /* should not write() to random destinations */
+  assert(!nepim_global.udp_dst_random_addr && !nepim_global.udp_dst_random_port);
+
   slot_buf_write(slot, buf, buf_size, type);
 
   wr = write(slot->udp_sd, buf, buf_size);
