@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: sock.c,v 1.41 2006/06/07 15:27:43 evertonm Exp $ */
+/* $Id: sock.c,v 1.42 2007/08/16 22:02:13 evertonm Exp $ */
 
 #include <assert.h>
 #include <netdb.h>
@@ -108,6 +108,21 @@ int nepim_sock_get_port(const struct sockaddr *addr)
   return ntohs(sa->inet.sin_port);
 }
 
+void nepim_sock_set_port(const struct sockaddr *addr, int port)
+{
+  union {
+    struct sockaddr_in inet;
+    struct sockaddr_in6 inet6;
+  } *sa = (void *) addr;
+
+  assert(nepim_sock_family(addr) != AF_UNIX);
+
+  assert(&(sa->inet.sin_port) == &(sa->inet6.sin6_port));
+  assert(sa->inet.sin_port == sa->inet6.sin6_port);
+
+  sa->inet.sin_port = htons(port);
+}
+
 int nepim_sock_family(const struct sockaddr *addr)
 {
   union {
