@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.80 2007/03/22 21:56:53 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.81 2007/08/16 22:02:13 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -738,7 +738,15 @@ static void udp_write_rate(nepim_slot_t *slot)
   assert(to_write >= UDP_HEADER_LEN);
   assert(to_write <= sweep_write);
 
-  wr = nepim_slot_buf_write(slot, buf, to_write, UDP_TYPE_DATA);
+  /* _write() is nicer, but only _sendto() 
+     can perform address randomization */
+
+  if (nepim_global.udp_dst_random_addr ||
+      nepim_global.udp_dst_random_port)
+    wr = nepim_slot_buf_sendto(slot, buf, to_write, UDP_TYPE_DATA);
+  else
+    wr = nepim_slot_buf_write(slot, buf, to_write, UDP_TYPE_DATA);
+
   if (wr < 0) {
     switch (errno) {
     case EINTR:
@@ -827,7 +835,15 @@ static void udp_write_full(nepim_slot_t *slot)
   assert(to_write >= UDP_HEADER_LEN);
   assert(to_write <= (sizeof buf));
 
-  wr = nepim_slot_buf_write(slot, buf, to_write, UDP_TYPE_DATA);
+  /* _write() is nicer, but only _sendto() 
+     can perform address randomization */
+
+  if (nepim_global.udp_dst_random_addr ||
+      nepim_global.udp_dst_random_port)
+    wr = nepim_slot_buf_sendto(slot, buf, to_write, UDP_TYPE_DATA);
+  else
+    wr = nepim_slot_buf_write(slot, buf, to_write, UDP_TYPE_DATA);
+
   if (wr < 0) {
     switch (errno) {
     case EINTR:
@@ -899,6 +915,8 @@ static void *on_udp_write(oop_source *src, int sd,
 
   if (!session->must_send) {
     if (session->keepalive_must_send) {
+      /* should not send keepalive for random destinations */ 
+      assert(!nepim_global.udp_dst_random_addr && !nepim_global.udp_dst_random_port);
       nepim_udp_write_keepalive(slot, nepim_slot_buf_write,
                                 on_udp_keepalive_time, udp_slot_kill);
       return OOP_CONTINUE;
