@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.103 2006/08/15 13:20:33 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.105 2007/03/23 12:40:05 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -603,13 +603,20 @@ static void *on_udp_keepalive_time(oop_source *src, struct timeval tv, void *use
   assert(!session->must_send);
   assert(session->keepalive_must_send);
 
+#ifdef NEPIM_DEBUG_KEEPALIVE
+  fprintf(stderr,
+          "NEPIM_DEBUG_KEEPALIVE %s %s: keepalive_send_delay=%ld\n",
+          __FILE__, __PRETTY_FUNCTION__,
+          session->keepalive_send_delay);
+#endif
+
   /* save next scheduling time */
   {
     int result = gettimeofday(&session->tv_keepalive_send_next, 0);
     assert(!result);
   }
   nepim_timer_usec_add(&session->tv_keepalive_send_next,
-		       nepim_global.udp_keepalive_send_delay);
+		       session->keepalive_send_delay);
 
   /* start to write */
   nepim_will_slot_keepalive(slot, on_udp_write);
@@ -783,7 +790,7 @@ static int parse_greetings(nepim_greet_t *opt,
   opt->password_buf = password_buf;
   opt->password_buf_size = sizeof(password_buf);
 
-  result = nepim_parse_greetings(opt, buf, past_end);
+  result = nepim_parse_greetings(opt, 0 /* is_tcp=false */, buf, past_end);
   if (result)
     return result;
 
@@ -793,8 +800,8 @@ static int parse_greetings(nepim_greet_t *opt,
 
   fprintf(stderr, 
 	  "%d %d-%d: UDP from (%s,%d): send=%d bps=%lld pps=%d "
-	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d seed=0x%08x "
-	  "verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
+	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d ka_tmout=%d ka_delay=%d "
+          "seed=0x%08x verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
 	  "sock_ka=%d overhead=%d "
 	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
 	  "password=%s\n", 
@@ -805,7 +812,8 @@ static int parse_greetings(nepim_greet_t *opt,
 	  opt->must_send, opt->bit_rate, opt->pkt_rate,
 	  opt->stat_interval, opt->test_duration, 
 	  opt->write_delay, opt->keepalive_must_send,
-	  opt->keepalive_require, opt->seed,
+	  opt->keepalive_require, opt->keepalive_timeout, opt->keepalive_send_delay,
+          opt->seed,
 	  opt->verify_data, opt->random_fill, opt->fill_byte,
 	  opt->pause_duration, opt->socket_keepalive,
 	  opt->overhead,
